@@ -57,6 +57,17 @@ int JackClient::wrapJackProcess(jack_nframes_t nframes, void* arg)
 	return static_cast<JackClient*>(arg)->process(nframes);
 }
 
+void JackClient::latencyCallback(jack_latency_callback_mode_t mode,
+                                 void* arg)
+{
+	static_cast<JackClient*>(arg)->jackLatencyCallback(mode);
+}
+
+void JackClient::freewheelCallback(int is_freewheeling, void* arg)
+{
+	static_cast<JackClient*>(arg)->jackFreewheelCallback(is_freewheeling);
+}
+
 JackClient::JackClient()
 	: client{nullptr}
 	, processes{}
@@ -64,7 +75,11 @@ JackClient::JackClient()
 {
 	jack_status_t status;
 	client = jack_client_open("DrumGizmo", JackNullOption, &status);
+
+	// Register callbacks
 	jack_set_process_callback(client, JackClient::wrapJackProcess, this);
+	jack_set_latency_callback(client, JackClient::latencyCallback, this);
+	jack_set_freewheel_callback(client, JackClient::freewheelCallback, this);
 }
 
 JackClient::~JackClient()
@@ -103,6 +118,19 @@ int JackClient::process(jack_nframes_t num_frames)
 	return 0;
 }
 
+void JackClient::jackLatencyCallback(jack_latency_callback_mode_t mode)
+{
+	for(auto& ptr : processes)
+	{
+		ptr->jackLatencyCallback(mode);
+	}
+}
+
+void JackClient::jackFreewheelCallback(bool is_freewheeling)
+{
+	this->is_freewheeling = is_freewheeling;
+}
+
 std::size_t JackClient::getBufferSize() const
 {
 	return jack_get_buffer_size(client);
@@ -112,3 +140,8 @@ std::size_t JackClient::getSampleRate() const
 {
 	return jack_get_sample_rate(client);
 }
+
+bool JackClient::isFreewheeling() const
+{
+	return is_freewheeling;
+}
