@@ -26,6 +26,8 @@
  */
 #include "drumgizmo_plugin.h"
 
+#include <config.h>
+
 #include <cstring>
 #include <algorithm>
 #include <string>
@@ -39,7 +41,7 @@
 
 #ifdef LV2
 // Entry point for lv2 plugin instantiation.
-PluginLV2* createEffectInstance()
+PG_EXPORT PluginLV2* createEffectInstance()
 {
 	return new DrumGizmoPlugin();
 }
@@ -110,7 +112,7 @@ size_t DrumGizmoPlugin::getNumberOfAudioInputs()
 
 size_t DrumGizmoPlugin::getNumberOfAudioOutputs()
 {
-	return 16;
+	return NUM_CHANNELS;
 }
 
 std::string DrumGizmoPlugin::getId()
@@ -118,6 +120,11 @@ std::string DrumGizmoPlugin::getId()
 	return "DrumGizmo";
 }
 
+std::string DrumGizmoPlugin::getURI()
+{
+	return "http://drumgizmo.org";
+}
+
 std::string DrumGizmoPlugin::getEffectName()
 {
 	return "DrumGizmo";
@@ -133,12 +140,17 @@ std::string DrumGizmoPlugin::getProductString()
 	return "DrumGizmo";
 }
 
+std::string DrumGizmoPlugin::getHomepage()
+{
+	return "https://www.drumgizmo.org";
+}
+
 PluginCategory DrumGizmoPlugin::getPluginCategory()
 {
 	return PluginCategory::Synth;
 }
 
-static float g_samples[16*  4096];
+static float g_samples[NUM_CHANNELS *  4096];
 
 void DrumGizmoPlugin::process(size_t pos,
                               const std::vector<MidiEvent>& input_events,
@@ -200,48 +212,86 @@ void DrumGizmoPlugin::onInlineRedraw(std::size_t width,
                                      std::size_t max_height,
                                      InlineDrawContext& context)
 {
-	std::size_t height = std::min(std::size_t(11), max_height);
-	if(!context.data ||
-	   (context.width != width) ||
-	   (context.height != height) ||
-	   settingsGetter.number_of_files.hasChanged() ||
-	   settingsGetter.number_of_files_loaded.hasChanged() ||
-	   settingsGetter.drumkit_load_status.hasChanged())
+	std::size_t bar_height = bar_red.height();
+	std::size_t image_height = ((double)width / inline_display_image.width()) * inline_display_image.height();
+
+	bool show_bar{false};
+	bool show_image{false};
+	std::size_t height = 0;
+
+	if(bar_height <= max_height)
+	{
+		show_bar = true;
+		height += bar_height;
+	}
+	if(bar_height + image_height <= max_height)
+	{
+		show_image = true;
+		height += image_height;
+	}
+
+	// They have to be called seperately to avoid lazy evaluation
+	bool nof_changed = settingsGetter.number_of_files.hasChanged();
+	bool nofl_changed = settingsGetter.number_of_files_loaded.hasChanged();
+	bool dls_changed = settingsGetter.drumkit_load_status.hasChanged();
+
+	bool context_needs_update =
+	    !context.data || context.width != width || context.height != height;
+	bool bar_needs_update =
+		nof_changed || nofl_changed || dls_changed || context_needs_update;
+	bool image_needs_update = inline_image_first_draw || context_needs_update;
+	// TODO: settingsGetter.inline_image_filename.hasChanged();
+	bool something_needs_update =
+	    context_needs_update || bar_needs_update || image_needs_update;
+
+	if (something_needs_update)
 	{
 		context.width = width;
 		context.height = height;
 		assert(context.width * context.height <= sizeof(inlineDisplayBuffer));
 
 		context.data = (unsigned char*)inlineDisplayBuffer;
-		box.setSize(context.width, context.height);
-
 		InlineCanvas canvas(context);
 		GUI::Painter painter(canvas);
-		painter.clear();
-		painter.drawImage(0, 0, box);
 
-		double progress =
-			(double)settingsGetter.number_of_files_loaded.getValue() /
-			(double)settingsGetter.number_of_files.getValue();
-
-		int brd = 4;
-		int val = (width - (2 * brd)) * progress;
-
-		switch(settingsGetter.drumkit_load_status.getValue())
+		if(show_bar && bar_needs_update)
 		{
-		case LoadStatus::Error:
-			bar_red.setSize(val, height);
-			painter.drawImage(brd, 0, bar_red);
-			break;
-		case LoadStatus::Done:
-			bar_green.setSize(val, height);
-			painter.drawImage(brd, 0, bar_green);
-			break;
-		case LoadStatus::Loading:
-		case LoadStatus::Idle:
-			bar_blue.setSize(val, height);
-			painter.drawImage(brd, 0, bar_blue);
-			break;
+			box.setSize(context.width, bar_height);
+			painter.drawImage(0, height - bar_height, box);
+
+			double progress =
+				(double)settingsGetter.number_of_files_loaded.getValue() /
+				(double)settingsGetter.number_of_files.getValue();
+
+			int brd = 4;
+			int val = (width - (2 * brd)) * progress;
+
+			switch(settingsGetter.drumkit_load_status.getValue())
+			{
+			case LoadStatus::Error:
+				bar_red.setSize(val, bar_height);
+				painter.drawImage(brd, height - bar_height, bar_red);
+				break;
+			case LoadStatus::Done:
+				bar_green.setSize(val, bar_height);
+				painter.drawImage(brd, height - bar_height, bar_green);
+				break;
+			case LoadStatus::Loading:
+			case LoadStatus::Idle:
+				bar_blue.setSize(val, bar_height);
+				painter.drawImage(brd, height - bar_height, bar_blue);
+				break;
+			}
+		}
+
+		if(show_image && image_needs_update)
+		{
+			// TODO: load new image and remove the bool
+			inline_image_first_draw = false;
+
+			painter.setColour(.5);
+			painter.drawFilledRectangle(0, 0, width, image_height);
+			painter.drawImageStretched(0, 0, inline_display_image, width, image_height);
 		}
 
 		// Convert to correct pixel format
@@ -259,7 +309,7 @@ bool DrumGizmoPlugin::hasGUI()
 	return true;
 }
 
-void* DrumGizmoPlugin::createWindow(void *parent)
+void* DrumGizmoPlugin::createWindow(void* parent)
 {
 	plugin_gui = std::make_shared<GUI::MainWindow>(settings, parent);
 	resizeWindow(width, height);
@@ -334,16 +384,8 @@ void DrumGizmoPlugin::Input::run(size_t pos, size_t len, std::vector<event_t>& e
 
 	for(auto& event : *plugin.input_events)
 	{
-		if(event.type !=  MidiEventType::NoteOn)
-		{
-			continue;
-		}
-
-		int i = mmap.lookup(event.key);
-		if(event.velocity && (i != -1))
-		{
-			events.push_back({TYPE_ONSET, (size_t)i, (size_t)event.getTime(), event.velocity / 127.0f});
-		}
+		processNote((const std::uint8_t*)event.getData(), event.getSize(),
+		            event.getTime(), events);
 	}
 }
 
@@ -356,6 +398,25 @@ bool DrumGizmoPlugin::Input::isFreewheeling() const
 	return plugin.getFreeWheel();
 }
 
+bool DrumGizmoPlugin::Input::loadMidiMap(const std::string& file,
+                                         const Instruments& i)
+{
+	bool result = AudioInputEngineMidi::loadMidiMap(file, i);
+	std::vector<std::pair<int, std::string>> midnam;
+
+	const auto& map = mmap.getMap();
+	midnam.reserve(map.size());
+	for(const auto& m : map)
+	{
+		midnam.push_back(std::make_pair(m.first, m.second));
+	}
+
+	if(midnam.size() > 0)
+	{
+		plugin.setMidnamData(midnam);
+	}
+	return result;
+}
 
 //
 // Output Engine
@@ -396,7 +457,7 @@ void DrumGizmoPlugin::Output::pre(size_t nsamples)
 	}
 }
 
-void DrumGizmoPlugin::Output::run(int ch, sample_t *samples, size_t nsamples)
+void DrumGizmoPlugin::Output::run(int ch, sample_t* samples, size_t nsamples)
 {
 	assert(plugin.output_samples);
 
@@ -441,6 +502,11 @@ size_t DrumGizmoPlugin::Output::getBufferSize() const
 	return plugin.getFramesize();
 }
 
+std::size_t DrumGizmoPlugin::Output::getSamplerate() const
+{
+	return plugin.drumgizmo->samplerate();
+}
+
 bool DrumGizmoPlugin::Output::isFreewheeling() const
 {
 	return plugin.getFreeWheel();
@@ -495,6 +561,18 @@ int str2int(std::string a)
 	}
 }
 
+long long str2ll(std::string a)
+{
+	try
+	{
+		return std::stoll(a);
+	}
+	catch(...)
+	{
+		return 0;
+	}
+}
+
 } // end anonymous namespace
 
 DrumGizmoPlugin::ConfigStringIO::ConfigStringIO(Settings& settings)
@@ -506,7 +584,7 @@ DrumGizmoPlugin::ConfigStringIO::ConfigStringIO(Settings& settings)
 std::string DrumGizmoPlugin::ConfigStringIO::get()
 {
 	return
-		"<config>\n"
+		"<config version=\"1.0\">\n"
 		"  <value name=\"drumkitfile\">" + settings.drumkit_file.load() + "</value>\n"
 		"  <value name=\"midimapfile\">" + settings.midimap_file.load() + "</value>\n"
 		"  <value name=\"enable_velocity_modifier\">" +
@@ -515,6 +593,14 @@ std::string DrumGizmoPlugin::ConfigStringIO::get()
 		float2str(settings.velocity_modifier_falloff.load()) + "</value>\n"
 		"  <value name=\"velocity_modifier_weight\">" +
 		float2str(settings.velocity_modifier_weight.load()) + "</value>\n"
+		"  <value name=\"velocity_stddev\">" +
+		float2str(settings.velocity_stddev.load()) + "</value>\n"
+		"  <value name=\"sample_selection_f_close\">" +
+		float2str(settings.sample_selection_f_close.load()) + "</value>\n"
+		"  <value name=\"sample_selection_f_diverse\">" +
+		float2str(settings.sample_selection_f_diverse.load()) + "</value>\n"
+		"  <value name=\"sample_selection_f_random\">" +
+		float2str(settings.sample_selection_f_random.load()) + "</value>\n"
 		"  <value name=\"enable_velocity_randomiser\">" +
 		bool2str(settings.enable_velocity_randomiser.load()) + "</value>\n"
 		"  <value name=\"velocity_randomiser_weight\">" +
@@ -527,6 +613,21 @@ std::string DrumGizmoPlugin::ConfigStringIO::get()
 		int2str(settings.disk_cache_chunk_size.load()) + "</value>\n"
 		"  <value name=\"disk_cache_enable\">" +
 		bool2str(settings.disk_cache_enable.load()) + "</value>\n"
+		"  <value name=\"enable_bleed_control\">" +
+		bool2str(settings.enable_bleed_control.load()) + "</value>\n"
+		"  <value name=\"master_bleed\">" +
+		float2str(settings.master_bleed.load()) + "</value>\n"
+		"  <value name=\"enable_latency_modifier\">" +
+		bool2str(settings.enable_latency_modifier.load()) + "</value>\n"
+		// Do not store/reload this value
+		//"  <value name=\"latency_max\">" +
+		//int2str(settings.latency_max.load()) + "</value>\n"
+		"  <value name=\"latency_laid_back_ms\">" +
+		float2str(settings.latency_laid_back_ms.load()) + "</value>\n"
+		"  <value name=\"latency_stddev\">" +
+		float2str(settings.latency_stddev.load()) + "</value>\n"
+		"  <value name=\"latency_regain\">" +
+		float2str(settings.latency_regain.load()) + "</value>\n"
 		"</config>";
 }
 
@@ -535,7 +636,7 @@ bool DrumGizmoPlugin::ConfigStringIO::set(std::string config_string)
 	DEBUG(config, "Load config: %s\n", config_string.c_str());
 
 	ConfigParser p;
-	if(p.parseString(config_string))
+	if(!p.parseString(config_string))
 	{
 		ERR(config, "Config parse error.\n");
 		return false;
@@ -556,6 +657,26 @@ bool DrumGizmoPlugin::ConfigStringIO::set(std::string config_string)
 		settings.velocity_modifier_weight.store(str2float(p.value("velocity_modifier_weight")));
 	}
 
+	if(p.value("velocity_stddev") != "")
+	{
+		settings.velocity_stddev.store(str2float(p.value("velocity_stddev")));
+	}
+
+	if(p.value("sample_selection_f_close") != "")
+	{
+		settings.sample_selection_f_close.store(str2float(p.value("sample_selection_f_close")));
+	}
+
+	if(p.value("sample_selection_f_diverse") != "")
+	{
+		settings.sample_selection_f_diverse.store(str2float(p.value("sample_selection_f_diverse")));
+	}
+
+	if(p.value("sample_selection_f_random") != "")
+	{
+		settings.sample_selection_f_random.store(str2float(p.value("sample_selection_f_random")));
+	}
+
 	if(p.value("enable_velocity_randomiser") != "")
 	{
 		settings.enable_velocity_randomiser.store(p.value("enable_velocity_randomiser") == "true");
@@ -573,7 +694,7 @@ bool DrumGizmoPlugin::ConfigStringIO::set(std::string config_string)
 
 	if(p.value("disk_cache_upper_limit") != "")
 	{
-		settings.disk_cache_upper_limit.store(str2int(p.value("disk_cache_upper_limit")));
+		settings.disk_cache_upper_limit.store(str2ll(p.value("disk_cache_upper_limit")));
 	}
 
 	if(p.value("disk_cache_chunk_size") != "")
@@ -586,6 +707,42 @@ bool DrumGizmoPlugin::ConfigStringIO::set(std::string config_string)
 		settings.disk_cache_enable.store(p.value("disk_cache_enable") == "true");
 	}
 
+	if(p.value("enable_bleed_control") != "")
+	{
+		settings.enable_bleed_control.store(p.value("enable_bleed_control") == "true");
+	}
+
+	if(p.value("master_bleed") != "")
+	{
+		settings.master_bleed.store(str2float(p.value("master_bleed")));
+	}
+
+	if(p.value("enable_latency_modifier") != "")
+	{
+		settings.enable_latency_modifier.store(p.value("enable_latency_modifier") == "true");
+	}
+
+	// Do not store/reload this value
+	//if(p.value("latency_max") != "")
+	//{
+	//	settings.latency_max.store(str2int(p.value("latency_max")));
+	//}
+
+	if(p.value("latency_laid_back_ms") != "")
+	{
+		settings.latency_laid_back_ms.store(str2float(p.value("latency_laid_back_ms")));
+	}
+
+	if(p.value("latency_stddev") != "")
+	{
+		settings.latency_stddev.store(str2float(p.value("latency_stddev")));
+	}
+
+	if(p.value("latency_regain") != "")
+	{
+		settings.latency_regain.store(str2float(p.value("latency_regain")));
+	}
+
 	std::string newkit = p.value("drumkitfile");
 	if(newkit != "")
 	{
