@@ -26,7 +26,7 @@
  */
 #include "pluginlv2.h"
 
-#include <iostream>
+#include <sstream>
 #include <assert.h>
 
 #include "midievent.h"
@@ -39,6 +39,15 @@
 #include <lv2/lv2plug.in/ns/ext/midi/midi.h>
 #include <lv2/lv2plug.in/ns/ext/instance-access/instance-access.h>
 
+void PluginLV2::init()
+{
+	for(auto& m : midnamData)
+	{
+		m.first = -1; // Mark midnam slot as unsued.
+		m.second.reserve(64); // Reserve 64 characters for the midnam name.
+	}
+}
+
 bool PluginLV2::getFreeWheel() const
 {
 	return free_wheel;
@@ -121,6 +130,13 @@ LV2_Handle PluginLV2::instantiate(const struct _LV2_Descriptor* descriptor,
 		}
 #endif
 
+#ifdef MIDNAM_INTERFACE
+		if(uri == LV2_MIDNAM__update)
+		{
+			plugin_lv2->midnam = (LV2_Midnam*)data;
+		}
+#endif
+
 		++features;
 	}
 
@@ -252,20 +268,19 @@ _lv2_atom_sequence_append_event(LV2_Atom_Sequence* seq,
 
 void Sequence::addMidiEvent(std::size_t pos, const char* data, std::size_t size)
 {
-	typedef struct {
+	struct MIDINoteEvent {
 		LV2_Atom_Event event;
 		uint8_t        msg[6];
-	} MIDINoteEvent;
-
+	};
 
 	MIDINoteEvent ev;
 	ev.event.time.frames = pos;
 	ev.event.body.type = map.map(map.handle, LV2_MIDI__MidiEvent);
-	ev.event.body.size = size;//sizeof(LV2_Atom_Event) + size;
+	ev.event.body.size = size;
 
 	assert(size <= sizeof(ev.msg)); // Assert that we have room for the message
 
-	memcpy(ev.msg, data, size + sizeof(LV2_Atom_Event));
+	memcpy(ev.msg, data, size);
 
 	_lv2_atom_sequence_append_event(seq, this->buffer_size, &ev.event);
 }
@@ -356,6 +371,14 @@ void PluginLV2::run(LV2_Handle instance, uint32_t sample_count)
 
 	plugin_lv2->pos += sample_count;
 
+#ifdef MIDNAM_INTERFACE
+	if(plugin_lv2->midnam && plugin_lv2->midnam_changed.load())
+	{
+		plugin_lv2->midnam->update(plugin_lv2->midnam->handle);
+		plugin_lv2->midnam_changed.store(false);
+	}
+#endif
+
 #ifdef DISPLAY_INTERFACE
 	if(plugin_lv2->queue_draw)
 	{
@@ -471,6 +494,98 @@ LV2_Inline_Display_Image_Surface* PluginLV2::inlineRender(LV2_Handle instance,
 	return &plugin_lv2->surf;
 }
 
+void PluginLV2::setMidnamData(const std::vector<std::pair<int, std::string>>& midnam)
+{
+	auto idx = 0u;
+	for(const auto& m : midnam)
+	{
+		midnamData[idx].first = m.first;
+		// Duplicate name making sure no reallocation is being performed.
+		midnamData[idx].second =
+			m.second.substr(0, midnamData[idx].second.capacity() - 1);
+		idx++;
+	}
+	for(;idx < this->midnamData.size(); ++idx)
+	{
+		midnamData[idx].first = -1; // Mark as unused
+	}
+	midnam_changed.store(true);
+}
+
+#ifdef MIDNAM_INTERFACE
+char* PluginLV2::MidnamFile (LV2_Handle instance)
+{
+	PluginLV2* plugin_lv2 = (PluginLV2*)instance;
+	std::stringstream ss;
+	ss <<
+		"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+		"<!DOCTYPE MIDINameDocument PUBLIC \"-//MIDI Manufacturers Association//DTD MIDINameDocument 1.0//EN\" \"http://dev.midi.org/dtds/MIDINameDocument10.dtd\">\n"
+		"<MIDINameDocument>\n"
+		"  <Author/>\n"
+		"  <MasterDeviceNames>\n"
+		"    <Manufacturer>" << plugin_lv2->getVendorString() << "</Manufacturer>\n"
+		"    <Model>" << plugin_lv2->getProductString() << ":" << ((const void *) instance) << "</Model>\n"; //<< needs to match MidnamModel()
+
+	ss << "    <CustomDeviceMode Name=\"Default\">\n";
+	ss << "      <ChannelNameSetAssignments>\n";
+	for (int c = 0; c < 16; ++c)
+	{
+		ss << "        <ChannelNameSetAssign Channel=\"" << (c + 1) << "\" NameSet=\"Presets\"/>\n";
+	}
+	ss << "      </ChannelNameSetAssignments>\n";
+	ss << "    </CustomDeviceMode>\n";
+
+
+	ss <<
+		"    <ChannelNameSet Name=\"Presets\">\n"
+		"      <AvailableForChannels>\n";
+	for (int c = 0; c < 16; ++c) {
+		ss << "        <AvailableChannel Channel=\"" << (c + 1) << "\" Available=\"true\"/>\n";
+	}
+	ss <<
+		"      </AvailableForChannels>\n"
+		"      <UsesNoteNameList Name=\"Notes\"/>\n"
+		"      <PatchBank Name=\"User Patches\">\n"
+		"        <PatchNameList Name=\"User Patches\"/>\n"
+		"       </PatchBank>\n"
+		"    </ChannelNameSet>\n"
+		"    <NoteNameList Name=\"Notes\">\n";
+	// TODO: Fill in empty slots for the notes that are not in the map
+	// Does Ardour preserve the note names for the unspecified notes?
+	// ... and is this a bug??
+	for(const auto& m : plugin_lv2->midnamData)
+	{
+		if(m.first == -1)
+		{
+			continue;
+		}
+		ss << "      <Note Number=\"" << m.first << "\" Name=\""<< m.second << "\"/>\n";
+	}
+
+	ss <<
+		"    </NoteNameList>\n"
+		"  </MasterDeviceNames>\n"
+		"</MIDINameDocument>";
+
+	return strdup (ss.str().c_str());
+}
+
+char* PluginLV2::MidnamModel(LV2_Handle instance)
+{
+	PluginLV2* plugin_lv2 = (PluginLV2*)instance;
+	char* rv = (char*) malloc (64 * sizeof (char));
+	snprintf(rv, 64, "%s:%p",
+	         plugin_lv2->getProductString().data(), (void*) instance);
+	rv[63] = 0;
+	return rv;
+}
+
+void  PluginLV2::MidnamFree  (char* v)
+{
+	free (v);
+}
+#endif
+
 const void* PluginLV2::extensionData(const char *uri)
 {
 	if(!strcmp(uri, LV2_STATE__interface))
@@ -486,6 +601,14 @@ const void* PluginLV2::extensionData(const char *uri)
 	}
 #endif
 
+#ifdef MIDNAM_INTERFACE
+	static const LV2_Midnam_Interface midnam = { MidnamFile, MidnamModel, MidnamFree };
+	if (!strcmp (uri, LV2_MIDNAM__interface))
+	{
+		return &midnam;
+	}
+#endif
+
 	return nullptr;
 }
 
