@@ -48,6 +48,11 @@ Image::Image(const std::string& filename)
 	: filename(filename)
 {
 	Resource rc(filename);
+	if(!rc.valid())
+	{
+		setError();
+		return;
+	}
 	load(rc.data(), rc.size());
 }
 
@@ -71,25 +76,33 @@ Image& Image::operator=(Image&& other)
 	image_data = std::move(other.image_data);
 	_width = other._width;
 	_height = other._height;
+	valid = other.valid;
 
 	other._width = 0;
 	other._height = 0;
-
+	other.valid = false;
 	return *this;
 }
 
 void Image::setError()
 {
+	valid = false;
 	Resource rc(":resources/png_error");
 
 	const unsigned char* ptr = (const unsigned char*)rc.data();
 
 	std::uint32_t iw, ih;
 
-	std::memcpy(&iw, ptr, sizeof(uint32_t));
+	iw = (uint32_t) ptr[0] |
+	     (uint32_t) ptr[1] << 8 |
+	     (uint32_t) ptr[2] << 16 |
+	     (uint32_t) ptr[3] << 24;
 	ptr += sizeof(uint32_t);
 
-	std::memcpy(&ih, ptr, sizeof(uint32_t));
+	ih = (uint32_t) ptr[0] |
+	     (uint32_t) ptr[1] << 8 |
+	     (uint32_t) ptr[2] << 16 |
+	     (uint32_t) ptr[3] << 24;
 	ptr += sizeof(uint32_t);
 
 	_width = iw;
@@ -113,10 +126,10 @@ void Image::setError()
 void Image::load(const char* data, size_t size)
 {
 	unsigned int iw{0}, ih{0};
-	unsigned char* char_image_data{nullptr};
-	unsigned int res = lodepng_decode32((unsigned char**)&char_image_data,
+	std::uint8_t* char_image_data{nullptr};
+	unsigned int res = lodepng_decode32((std::uint8_t**)&char_image_data,
 	                                    &iw, &ih,
-	                                    (const unsigned char*)data, size);
+	                                    (const std::uint8_t*)data, size);
 
 	if(res != 0)
 	{
@@ -136,15 +149,15 @@ void Image::load(const char* data, size_t size)
 	{
 		for(std::size_t x = 0; x < _width; ++x)
 		{
-			unsigned char* ptr = &char_image_data[(x + y * _width) * 4];
-			image_data.emplace_back(Colour{ptr[0] / 255.0f, ptr[1] / 255.0f,
-						ptr[2] / 255.0f, ptr[3] / 255.0f});
+			std::uint8_t* ptr = &char_image_data[(x + y * _width) * 4];
+			image_data.emplace_back(Colour{ptr[0], ptr[1], ptr[2], ptr[3]});
 		}
 	}
 
 	assert(image_data.size() == (_width * _height));
 
 	std::free(char_image_data);
+	valid = true;
 }
 
 size_t Image::width() const
@@ -167,4 +180,9 @@ const Colour& Image::getPixel(size_t x, size_t y) const
 	return image_data[x + y * _width];
 }
 
+bool Image::isValid() const
+{
+	return valid;
+}
+
 } // GUI::
