@@ -61,6 +61,11 @@ void Knob::setValue(float value)
 	internalSetValue(value);
 }
 
+void Knob::setDefaultValue(float value)
+{
+	default_value = value;
+}
+
 void Knob::setRange(float minimum, float maximum)
 {
 	this->minimum = minimum;
@@ -145,10 +150,20 @@ void Knob::buttonEvent(ButtonEvent* buttonEvent)
 		return;
 	}
 
+	if(buttonEvent->doubleClick)
+	{
+		float value = default_value;
+		value -= minimum;
+		value /= (maximum - minimum);
+		internalSetValue(value);
+		return;
+	}
+
 	if(buttonEvent->direction == Direction::down)
 	{
 		state = down;
 		mouse_offset_x = buttonEvent->x + (-1 * buttonEvent->y);
+		return;
 	}
 
 	if(buttonEvent->direction == Direction::up)
@@ -156,6 +171,7 @@ void Knob::buttonEvent(ButtonEvent* buttonEvent)
 		state = up;
 		mouse_offset_x = buttonEvent->x + (-1 * buttonEvent->y);
 		clicked();
+		return;
 	}
 }
 
@@ -202,7 +218,7 @@ void Knob::repaintEvent(RepaintEvent* repaintEvent)
 	double to_y = cos((-1 * padval + 1) * 2 * M_PI) * radius * 0.8;
 
 	// Draw "fat" line by drawing 9 lines with moved start/ending points.
-	p.setColour(Colour(1, 0, 0, 1));
+	p.setColour(Colour(1.0f, 0.0f, 0.0f, 1.0f));
 	for(int _x = -1; _x < 2; _x++)
 	{
 		for(int _y = -1; _y < 2; _y++)
