@@ -106,7 +106,8 @@ void BoxLayout::setSpacing(size_t spacing)
 //
 
 VBoxLayout::VBoxLayout(LayoutItem* parent)
-    : BoxLayout(parent), align(HAlignment::center)
+	: BoxLayout(parent)
+	, align(HAlignment::center)
 {
 }
 
@@ -292,6 +293,35 @@ void GridLayout::setPosition(LayoutItem* item, GridRange const& range)
 	grid_ranges[item] = range;
 }
 
+int GridLayout::lastUsedRow(int column) const
+{
+	int last_row = -1;
+
+	for (auto const& grid_range : grid_ranges) {
+		auto const& range = grid_range.second;
+		if (column >= range.column_begin && column < range.column_end) {
+			last_row = std::max(last_row, range.row_end - 1);
+		}
+	}
+
+	return last_row;
+}
+
+int GridLayout::lastUsedColumn(int row) const
+{
+	int last_column = -1;
+
+	for (auto const& grid_range : grid_ranges) {
+		auto const& range = grid_range.second;
+		if (row >= range.row_begin && row < range.row_end) {
+			last_column = std::max(last_column, range.column_end - 1);
+		}
+	}
+
+	return last_column;
+
+}
+
 auto GridLayout::calculateCellSize() const -> CellSize
 {
 	auto empty_width = (number_of_columns - 1) * spacing;
@@ -315,7 +345,7 @@ auto GridLayout::calculateCellSize() const -> CellSize
 }
 
 void GridLayout::moveAndResize(
-    LayoutItem& item, GridRange const& range, CellSize cell_size) const
+	LayoutItem& item, GridRange const& range, CellSize cell_size) const
 {
 	std::size_t x = range.column_begin * (cell_size.width + spacing);
 	std::size_t y = range.row_begin * (cell_size.height + spacing);
@@ -340,15 +370,10 @@ void GridLayout::moveAndResize(
 	}
 	else
 	{
-		if(item.width() <= width && item.height() <= height)
-		{
-			item.move(x + (width - item.width()) / 2,
-			    y + (height - item.height()) / 2);
-		}
-		else
-		{
-			item.move(x, y);
-		}
+		auto x_new = (item.width() > width) ? x : x + (width - item.width()) / 2;
+		auto y_new = (item.height() > height) ? y : y + (height - item.height()) / 2;
+
+		item.move(x_new, y_new);
 	}
 }
 
