@@ -11,21 +11,20 @@
  *  This file is part of DrumGizmo.
  *
  *  DrumGizmo is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  DrumGizmo is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_LED_H__
-#define __DRUMGIZMO_LED_H__
+#pragma once
 
 #include "widget.h"
 
@@ -33,24 +32,23 @@ namespace GUI {
 
 class LED : public Widget {
 public:
-  typedef enum {
-    red,
-    green,
-    blue,
-    off
-  } state_t;
+	typedef enum {
+		Red,
+		Green,
+		Blue,
+		Off
+	} state_t;
 
-  LED(Widget *parent);
+	LED(Widget *parent);
 
-  void setState(state_t state);
+	void setState(state_t state);
 
-  //protected:
-  void repaintEvent(RepaintEvent *e);
+protected:
+	// From Widget:
+	void repaintEvent(RepaintEvent* repaintEvent) override;
 
 private:
-  state_t state;
+	state_t state;
 };
 
-};
-
-#endif/*__DRUMGIZMO_LED_H__*/
+} // GUI::
