@@ -212,7 +212,7 @@ void LineEdit::repaintEvent(RepaintEvent *repaintEvent)
 	box.setSize(w, h);
 	p.drawImage(0, 0, box);
 
-	p.setColour(Colour(183.0/255.0, 219.0/255.0 , 255.0/255.0, 1));
+	p.setColour(Colour(183.0f/255.0f, 219.0f/255.0f, 255.0f/255.0f, 1.0f));
 
 	switch(walkstate) {
 	case WalkLeft:
@@ -237,7 +237,7 @@ void LineEdit::repaintEvent(RepaintEvent *repaintEvent)
 	while(true)
 	{
 		int textWidth = font.textWidth(visibleText);
-		if(textWidth <= (w - BORDER - 4 + 3))
+		if(textWidth <= std::max(w - BORDER - 4 + 3, 0))
 		{
 			break;
 		}
