@@ -45,10 +45,11 @@ public:
 	~NativeWindowWin32();
 
 	void setFixedSize(std::size_t width, std::size_t height) override;
+	void setAlwaysOnTop(bool always_on_top) override;
 	void resize(std::size_t width, std::size_t height) override;
-	std::pair<std::size_t, std::size_t> getSize() override;
+	std::pair<std::size_t, std::size_t> getSize() const override;
 	void move(int x, int y) override;
-	std::pair<int, int> getPosition() override;
+	std::pair<int, int> getPosition() const override;
 	void show() override;
 	bool visible() const override;
 	void hide() override;
@@ -57,6 +58,7 @@ public:
 	void grabMouse(bool grab) override;
 	EventQueue getEvents() override;
 	void* getNativeWindowHandle() const override;
+	Point translateToScreen(const Point& point) override;
 
 private:
 	static LRESULT CALLBACK dialogProc(HWND hwnd, UINT msg, WPARAM wp, LPARAM lp);
@@ -66,8 +68,11 @@ private:
 	HWND parent_window;
 	Window& window;
 	WNDID m_hwnd = 0;
+	bool mouse_in_window{false};
+	std::pair<int, int> last_mouse_position{0, 0};
 	char* m_className = nullptr;
 	EventQueue event_queue;
+	bool always_on_top{false};
 };
 
 } // GUI::
