@@ -33,8 +33,8 @@
 #include <sys/shm.h>
 #include <cerrno>
 #include <cstring>
+#include <cassert>
 
-#include <stdlib.h>
 #include <chrono>
 
 #include <hugin.hpp>
@@ -44,6 +44,72 @@
 namespace GUI
 {
 
+#define _NET_WM_STATE_REMOVE        0    // remove/unset property
+#define _NET_WM_STATE_ADD           1    // add/set property
+
+void setWindowFront(Display *disp, ::Window wind, bool enable)
+{
+	Atom wm_state, wm_state_above;
+	XEvent event;
+
+	if((wm_state = XInternAtom(disp, "_NET_WM_STATE", False)) == None)
+	{
+		return;
+	}
+
+	if((wm_state_above = XInternAtom(disp, "_NET_WM_STATE_ABOVE", False)) == None)
+	{
+		return;
+	}
+	//
+	//window  = the respective client window
+	//message_type = _NET_WM_STATE
+	//format = 32
+	//data.l[0] = the action, as listed below
+	//data.l[1] = first property to alter
+	//data.l[2] = second property to alter
+	//data.l[3] = source indication (0-unk,1-normal app,2-pager)
+	//other data.l[] elements = 0
+	//
+
+	// sending a ClientMessage
+	event.xclient.type = ClientMessage;
+
+	// value unimportant in this case
+	event.xclient.serial = 0;
+
+	// coming from a SendEvent request, so True
+	event.xclient.send_event = True;
+
+	// the event originates from disp
+	event.xclient.display = disp;
+
+	// the window whose state will be modified
+	event.xclient.window = wind;
+
+	// the component Atom being modified in the window
+	event.xclient.message_type = wm_state;
+
+	// specifies that data.l will be used
+	event.xclient.format = 32;
+
+	// 0 is _NET_WM_STATE_REMOVE, 1 is _NET_WM_STATE_ADD
+	event.xclient.data.l[0] =
+		enable ? _NET_WM_STATE_ADD : _NET_WM_STATE_REMOVE;
+
+	// the atom being added
+	event.xclient.data.l[1] = wm_state_above;
+
+	// unused
+	event.xclient.data.l[2] = 0;
+	event.xclient.data.l[3] = 0;
+	event.xclient.data.l[4] = 0;
+
+	// actually send the event
+	XSendEvent(disp, DefaultRootWindow(disp), False,
+	           SubstructureRedirectMask | SubstructureNotifyMask, &event);
+}
+
 NativeWindowX11::NativeWindowX11(void* native_window, Window& window)
 	: window(window)
 {
@@ -92,15 +158,17 @@ NativeWindowX11::NativeWindowX11(void* native_window, Window& window)
 	             KeyReleaseMask|
 	             ExposureMask |
 	             StructureNotifyMask |
-	             SubstructureNotifyMask);
+	             SubstructureNotifyMask |
+	             EnterWindowMask |
+	             LeaveWindowMask);
 	XSelectInput(display, xwindow, mask);
 
 	// Register the delete window message:
 	wmDeleteMessage = XInternAtom(display, "WM_DELETE_WINDOW", false);
 
 	Atom protocols[] = { wmDeleteMessage };
-	int count = sizeof(protocols)/sizeof(Atom);
-	XSetWMProtocols(display, xwindow, protocols, count);
+	XSetWMProtocols(display, xwindow, protocols,
+	                sizeof(protocols) / sizeof(*protocols));
 
 	// Create a "Graphics Context"
 	gc = XCreateGC(display, xwindow, 0, nullptr);
@@ -130,25 +198,19 @@ void NativeWindowX11::setFixedSize(std::size_t width, std::size_t height)
 
 	resize(width, height);
 
-	XSizeHints* size_hints;
-	size_hints = XAllocSizeHints();
+	XSizeHints size_hints;
+	memset(&size_hints, 0, sizeof(size_hints));
 
-	if(size_hints == nullptr)
-	{
-		ERR(X11,"XMallocSizeHints() failed");
-		return;
-	}
+	size_hints.flags = PMinSize|PMaxSize;
+	size_hints.min_width = size_hints.max_width = (int)width;
+	size_hints.min_height = size_hints.max_height = (int)height;
 
-	size_hints->flags = USPosition | PMinSize | PMaxSize;
-	size_hints->min_width = size_hints->max_width = width;
-	size_hints->min_height = size_hints->max_height = height;
+	XSetNormalHints(display, xwindow, &size_hints);
+}
 
-	//size_hints->min_aspect.x = (float)window.width()/(float)window.height();
-	//size_hints->max_aspect.x = (float)window.width()/(float)window.height();
-	//size_hints->min_aspect.y = (float)window.width()/(float)window.height();
-	//size_hints->max_aspect.y = size_hints->min_aspect.y;
-
-	XSetWMNormalHints(display, xwindow, size_hints);
+void NativeWindowX11::setAlwaysOnTop(bool always_on_top)
+{
+	setWindowFront(display, xwindow, always_on_top);
 }
 
 void NativeWindowX11::resize(std::size_t width, std::size_t height)
@@ -161,7 +223,7 @@ void NativeWindowX11::resize(std::size_t width, std::size_t height)
 	XResizeWindow(display, xwindow, width, height);
 }
 
-std::pair<std::size_t, std::size_t> NativeWindowX11::getSize()
+std::pair<std::size_t, std::size_t> NativeWindowX11::getSize() const
 {
 //	XWindowAttributes attributes;
 //	XGetWindowAttributes(display, xwindow, &attributes);
@@ -175,7 +237,7 @@ std::pair<std::size_t, std::size_t> NativeWindowX11::getSize()
 	             &x, &y,
 	             &width, &height, &border, &depth);
 
-	return std::make_pair(width, height);
+	return {width, height};
 }
 
 void NativeWindowX11::move(int x, int y)
@@ -188,7 +250,7 @@ void NativeWindowX11::move(int x, int y)
 	XMoveWindow(display, xwindow, x, y);
 }
 
-std::pair<int, int> NativeWindowX11::getPosition()
+std::pair<int, int> NativeWindowX11::getPosition() const
 {
 	::Window root_window;
 	::Window child_window;
@@ -249,6 +311,10 @@ void NativeWindowX11::redraw(const Rect& dirty_rect)
 	auto x2 = dirty_rect.x2;
 	auto y2 = dirty_rect.y2;
 
+	// Assert that we don't try to paint a backwards rect.
+	assert(x1 <= x2);
+	assert(y1 <= y2);
+
 	updateImageFromBuffer(x1, y1, x2, y2);
 
 	XShmPutImage(display, xwindow, gc, image, x1, y1, x1, y1,
@@ -292,6 +358,15 @@ void* NativeWindowX11::getNativeWindowHandle() const
 	return (void*)xwindow;
 }
 
+Point NativeWindowX11::translateToScreen(const Point& point)
+{
+	::Window child_window;
+	Point p;
+	XTranslateCoordinates(display, xwindow, DefaultRootWindow(display),
+	                      point.x, point.y, &p.x, &p.y, &child_window);
+	return p;
+}
+
 void NativeWindowX11::translateXMessage(XEvent& xevent)
 {
 	switch(xevent.type)
@@ -363,12 +438,15 @@ void NativeWindowX11::translateXMessage(XEvent& xevent)
 		{
 			if((xevent.xbutton.button == 4) || (xevent.xbutton.button == 5))
 			{
-				int scroll = 1;
-				auto scrollEvent = std::make_shared<ScrollEvent>();
-				scrollEvent->x = xevent.xbutton.x;
-				scrollEvent->y = xevent.xbutton.y;
-				scrollEvent->delta = scroll * ((xevent.xbutton.button == 4) ? -1 : 1);
-				event_queue.push_back(scrollEvent);
+				if(xevent.type == ButtonPress)
+				{
+					int scroll = 1;
+					auto scrollEvent = std::make_shared<ScrollEvent>();
+					scrollEvent->x = xevent.xbutton.x;
+					scrollEvent->y = xevent.xbutton.y;
+					scrollEvent->delta = scroll * ((xevent.xbutton.button == 4) ? -1 : 1);
+					event_queue.push_back(scrollEvent);
+				}
 			}
 			else if ((xevent.xbutton.button == 6) || (xevent.xbutton.button == 7))
 			{
@@ -471,7 +549,25 @@ void NativeWindowX11::translateXMessage(XEvent& xevent)
 		break;
 
 	case EnterNotify:
+		//DEBUG(x11, "EnterNotify");
+		{
+			auto enterEvent = std::make_shared<MouseEnterEvent>();
+			enterEvent->x = xevent.xcrossing.x;
+			enterEvent->y = xevent.xcrossing.y;
+			event_queue.push_back(enterEvent);
+		}
+		break;
+
 	case LeaveNotify:
+		//DEBUG(x11, "LeaveNotify");
+		{
+			auto leaveEvent = std::make_shared<MouseLeaveEvent>();
+			leaveEvent->x = xevent.xcrossing.x;
+			leaveEvent->y = xevent.xcrossing.y;
+			event_queue.push_back(leaveEvent);
+		}
+		break;
+
 	case MapNotify:
 	case MappingNotify:
 		//DEBUG(x11, "EnterNotify");
