@@ -29,11 +29,11 @@
 #include <string>
 
 #include "colour.h"
+#include "pixelbuffer.h"
 
 namespace GUI
 {
 
-class PixelBufferAlpha;
 class Font;
 class Drawable;
 class Image;
@@ -56,9 +56,13 @@ public:
 	void drawCircle(int x, int y, double r);
 	void drawFilledCircle(int x, int y, int r);
 	void drawImage(int x, int y, const Drawable& image);
+	void drawRestrictedImage(int x0, int y0, Colour const& colour, const Drawable& image);
 	void drawImageStretched(int x, int y, const Drawable& image,
 	                        int width, int height);
 
+	template<typename Iterator>
+	void draw(Iterator begin, Iterator end, int x_offset, int y_offset, Colour const& colour);
+
 	typedef struct {
 		Image* topLeft;
 		Image* top;
@@ -82,8 +86,20 @@ public:
 	void clear();
 
 private:
+	bool has_restriction{false};
+	Colour restriction_colour;
+
 	PixelBufferAlpha& pixbuf;
 	Colour colour;
 };
 
+template<typename Iterator>
+void Painter::draw(Iterator begin, Iterator end, int x_offset, int y_offset, Colour const& colour)
+{
+	for (auto it = begin; it != end; ++it)
+	{
+		pixbuf.addPixel(x_offset + it->x, y_offset + it->y, colour);
+	}
+}
+
 } // GUI::
