@@ -37,6 +37,18 @@
 namespace GUI
 {
 
+struct Point
+{
+	int x;
+	int y;
+};
+
+struct Size
+{
+	std::size_t width;
+	std::size_t height;
+};
+
 class ImageCache;
 class Window;
 
@@ -66,6 +78,8 @@ public:
 	virtual std::size_t width() const override;
 	virtual std::size_t height() const override;
 
+	Point position() const;
+
 	// From Canvas
 	PixelBufferAlpha& GetPixelBuffer() override;
 
@@ -97,15 +111,14 @@ public:
 	Notifier<std::size_t, std::size_t> sizeChangeNotifier; // (width, height)
 	Notifier<int, int> positionChangeNotifier; // (x, y)
 
-protected:
-	friend class EventHandler;
-
 	//! Translate x-coordinate from parent-space to window-space.
 	virtual std::size_t translateToWindowX();
 
 	//! Translate y-coordinate from parent-space to window-space.
 	virtual std::size_t translateToWindowY();
 
+protected:
+	friend class EventHandler;
 	PixelBufferAlpha pixbuf{0,0};
 
 	std::vector<Widget*> children;
