@@ -86,6 +86,11 @@ void Window::setFixedSize(int w, int h)
 	native->setFixedSize(w, h);
 }
 
+void Window::setAlwaysOnTop(bool always_on_top)
+{
+	native->setAlwaysOnTop(always_on_top);
+}
+
 void Window::setCaption(const std::string& caption)
 {
 	native->setCaption(caption);
@@ -125,6 +130,12 @@ Window* Window::window()
 	return this;
 }
 
+Size Window::getNativeSize()
+{
+	auto sz = native->getSize();
+	return {sz.first, sz.second};
+}
+
 ImageCache& Window::getImageCache()
 {
 	return image_cache;
@@ -188,6 +199,11 @@ void* Window::getNativeWindowHandle() const
 	return native->getNativeWindowHandle();
 }
 
+Point Window::translateToScreen(const Point& point)
+{
+	return native->translateToScreen(point);
+}
+
 std::size_t Window::translateToWindowX()
 {
 	return 0;
@@ -358,6 +374,17 @@ bool Window::updateBuffer()
 	dirty_rect.x2 = std::min(wpixbuf.width, dirty_rect.x2);
 	dirty_rect.y2 = std::min(wpixbuf.height, dirty_rect.y2);
 
+	// Make sure we don't try to paint a rect backwards.
+	if(dirty_rect.x1 > dirty_rect.x2)
+	{
+		std::swap(dirty_rect.x1, dirty_rect.x2);
+	}
+
+	if(dirty_rect.y1 > dirty_rect.y2)
+	{
+		std::swap(dirty_rect.y1, dirty_rect.y2);
+	}
+
 	native->redraw(dirty_rect);
 	needs_redraw = false;
 
