@@ -38,22 +38,23 @@
 
 #include <hugin.hpp>
 
-#include "drumkitparser.h"
 #include "audioinputenginemidi.h"
 
 DrumGizmo::DrumGizmo(Settings& settings,
                      AudioOutputEngine& o, AudioInputEngine& i)
-	: loader(settings, kit, i, resamplers, rand, audio_cache)
+	: loader(settings, kit, i, rand, audio_cache)
 	, oe(o)
 	, ie(i)
 	, audio_cache(settings)
-	, input_processor(settings, kit, activeevents)
+	, input_processor(settings, kit, activeevents, rand)
 	, settings(settings)
 	, settings_getter(settings)
 {
 	audio_cache.init(10000); // start thread
 	events.reserve(1000);
 	loader.init();
+	setSamplerate(44100.0f);
+	settings_getter.audition_counter.hasChanged(); // Reset audition_counter
 }
 
 DrumGizmo::~DrumGizmo()
@@ -81,24 +82,12 @@ void DrumGizmo::setFrameSize(size_t framesize)
 {
 	settings.buffer_size.store(framesize);
 
-	// If we are resampling override the frame size.
-	if(resamplers.isActive() && enable_resampling)
-	{
-		framesize = RESAMPLER_INPUT_BUFFER;
-	}
-
 	if(this->framesize != framesize)
 	{
 		DEBUG(drumgizmo, "New framesize: %d\n", (int)framesize);
 
 		this->framesize = framesize;
 
-		// Remove all active events as they are cached using the old framesize.
-		for(std::size_t ch = 0; ch < MAX_NUM_CHANNELS; ++ch)
-		{
-			activeevents[ch].clear();
-		}
-
 		// Update framesize in drumkitloader and cachemanager:
 		loader.setFrameSize(framesize);
 		audio_cache.setFrameSize(framesize);
@@ -125,6 +114,12 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 		enable_resampling = settings_getter.enable_resampling.getValue();
 	}
 
+	if(settings_getter.drumkit_samplerate.hasChanged())
+	{
+		settings_getter.drumkit_samplerate.getValue(); // stage new value
+		setSamplerate(settings.samplerate.load());
+	}
+
 	setFrameSize(nsamples);
 	setFreeWheel(ie.isFreewheeling() && oe.isFreewheeling());
 
@@ -138,11 +133,30 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 
 	ie.run(pos, nsamples, events);
 
-	double resample_ratio = resamplers.getRatio();
+	double resample_ratio = ratio;
 	if(enable_resampling == false)
 	{
 		resample_ratio = 1.0;
 	}
+
+	if(settings_getter.audition_counter.hasChanged())
+	{
+		settings_getter.audition_counter.getValue();
+		auto instrument_name = settings.audition_instrument.load();
+		auto velocity = settings.audition_velocity.load();
+
+		std::size_t instrument_index = 0;
+		for (std::size_t i = 0; i < kit.instruments.size(); ++i)
+		{
+			if (instrument_name == kit.instruments[i]->getName())
+			{
+				instrument_index = i;
+			}
+		}
+
+		events.push_back({EventType::OnSet, instrument_index, 0, velocity});
+	}
+
 	bool active_events_left =
 		input_processor.process(events, pos, resample_ratio);
 
@@ -156,10 +170,10 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 	//
 	// Write audio
 	//
-#ifdef WITH_RESAMPLER
-	if(!enable_resampling || !resamplers.isActive()) // No resampling needed
+	if(!enable_resampling || ratio == 1.0)
 	{
-#endif
+		// No resampling needed
+
 		for(size_t c = 0; c < kit.channels.size(); ++c)
 		{
 			sample_t *buf = samples;
@@ -182,55 +196,45 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 				}
 			}
 		}
-#ifdef WITH_RESAMPLER
 	}
 	else
 	{
 		// Resampling needed
-
-		//
-		// NOTE: Channels must be processed one buffer at a time on all channels in
-		// parallel - NOT all buffers on one channel and then all buffer on the next
-		// one since this would mess up the event queue (it would jump back and
-		// forth in time)
-		//
-
-		// Prepare output buffer
+		size_t kitpos = pos * ratio;
 		for(size_t c = 0; c < kit.channels.size(); ++c)
 		{
-			resamplers[c].setOutputSamples(resampler_output_buffer[c], nsamples);
-		}
-
-		// Process channel data
-		size_t kitpos = pos * resamplers.getRatio();
-		size_t insize = sizeof(resampler_input_buffer[0]) / sizeof(sample_t);
-
-		while(resamplers.getOutputSampleCount() > 0)
-		{
-			for(size_t c = 0; c < kit.channels.size(); ++c)
+			sample_t *buf = samples;
+			bool internal = false;
+			if(oe.getBuffer(c))
 			{
-				if(resamplers[c].getInputSampleCount() == 0)
-				{
-					sample_t *sin = resampler_input_buffer[c];
-					memset(resampler_input_buffer[c], 0,
-					       sizeof(resampler_input_buffer[c]));
-					getSamples(c, kitpos, sin, insize);
-
-					resamplers[c].setInputSamples(sin, insize);
-				}
-				resamplers[c].process();
+				buf = oe.getBuffer(c);
+				internal = true;
 			}
-			kitpos += insize;
-		}
 
-		// Write output data to output engine.
-		for(size_t c = 0; c < kit.channels.size(); ++c)
-		{
-			oe.run(c, resampler_output_buffer[c], nsamples);
-		}
+			zita[c].out_data = buf;
+			zita[c].out_count = nsamples;
 
+			if(zita[c].inp_count > 0)
+			{
+				// Samples left from last iteration, process that one first
+				zita[c].process();
+			}
+
+			std::memset(resampler_input_buffer[c].get(), 0, MAX_RESAMPLER_BUFFER_SIZE);
+
+			zita[c].inp_data = resampler_input_buffer[c].get();
+			std::size_t sample_count =
+				std::ceil((nsamples - (nsamples - zita[c].out_count)) * ratio);
+			getSamples(c, kitpos, zita[c].inp_data, sample_count);
+
+			zita[c].inp_count = sample_count;
+			zita[c].process();
+			if(!internal)
+			{
+				oe.run(c, samples, nsamples);
+			}
+		}
 	}
-#endif/*WITH_RESAMPLER*/
 
 	ie.post();
 	oe.post(nsamples);
@@ -240,14 +244,84 @@ bool DrumGizmo::run(size_t pos, sample_t *samples, size_t nsamples)
 	return true;
 }
 
-#undef SSE // SSE broken for now ... so disable it.
-#ifdef SSE
-#define N 8
-typedef float vNsf __attribute__ ((vector_size(sizeof(sample_t)*N)));
-#endif/*SSE*/
+void DrumGizmo::renderSampleEvent(EventSample& evt, int pos, sample_t *s, std::size_t sz)
+{
+	size_t n = 0; // default start point is 0.
+
+	// If we are not at offset 0 in current buffer:
+	if(evt.offset > (size_t)pos)
+	{
+		n = evt.offset - pos;
+	}
+
+	size_t end = sz; // default end point is the end of the buffer.
+
+	// Find the end point intra-buffer
+	if((evt.t + end - n) > evt.sample_size)
+	{
+		end = evt.sample_size - evt.t + n;
+	}
+
+	// This should not be necessary but make absolutely sure that we do
+	// not write over the end of the buffer.
+	if(end > sz)
+	{
+		end = sz;
+	}
+
+	size_t t = 0; // Internal buffer counter
+
+repeat:
+	float scale = 1.0f;
+	for(; (n < end) && (t < (evt.buffer_size - evt.buffer_ptr)); ++n)
+	{
+		assert(n >= 0);
+		assert(n < sz);
+
+		assert(t >= 0);
+		assert(t < evt.buffer_size - evt.buffer_ptr);
+
+		if(evt.rampdownInProgress() && evt.rampdown_offset < (evt.t + t) &&
+		   evt.rampdown_count > 0)
+		{
+			if(evt.ramp_length > 0)
+			{
+				scale = std::min((float)evt.rampdown_count / evt.ramp_length, 1.f);
+			}
+			else
+			{
+				scale = 0.0f;
+			}
+			evt.rampdown_count--;
+		}
+
+		s[n] += evt.buffer[evt.buffer_ptr + t] * evt.scale * scale;
+		++t;
+	}
+
+	// Add internal buffer counter to "global" event counter.
+	evt.t += t;//evt.buffer_size;
+	evt.buffer_ptr += t;
+
+	if(n != sz && evt.t < evt.sample_size)
+	{
+		evt.buffer_size = sz - n;// Hint new size
+
+		// More samples needed for current buffer
+		evt.buffer = audio_cache.next(evt.cache_id, evt.buffer_size);
+
+		evt.buffer_ptr = 0;
+		t = 0;
+		goto repeat;
+	}
+}
 
 void DrumGizmo::getSamples(int ch, int pos, sample_t* s, size_t sz)
 {
+	// Store local values of settings to ensure they don't change intra-iteration
+	const auto enable_bleed_control = settings.enable_bleed_control.load();
+	const auto master_bleed = settings.master_bleed.load();
+
 	std::vector< Event* > erase_list;
 	std::list< Event* >::iterator i = activeevents[ch].begin();
 	for(; i != activeevents[ch].end(); ++i)
@@ -256,7 +330,8 @@ void DrumGizmo::getSamples(int ch, int pos, sample_t* s, size_t sz)
 
 		Event* event = *i;
 		Event::type_t type = event->getType();
-		switch(type) {
+		switch(type)
+		{
 		case Event::sample:
 			{
 				EventSample& evt = *static_cast<EventSample*>(event);
@@ -268,9 +343,9 @@ void DrumGizmo::getSamples(int ch, int pos, sample_t* s, size_t sz)
 					break;
 				}
 
-				// Don't handle event now is is scheduled for a future iteration?
 				if(evt.offset > (pos + sz))
 				{
+					// Don't handle event now. It is scheduled for a future iteration.
 					continue;
 				}
 
@@ -279,90 +354,33 @@ void DrumGizmo::getSamples(int ch, int pos, sample_t* s, size_t sz)
 					size_t initial_chunksize = (pos + sz) - evt.offset;
 					evt.buffer = audio_cache.open(af, initial_chunksize,
 					                              af.filechannel, evt.cache_id);
+					if((af.mainState() == main_state_t::is_not_main) &&
+					   enable_bleed_control)
+					{
+						evt.scale *= master_bleed;
+					}
+
 					evt.buffer_size = initial_chunksize;
+					evt.sample_size = af.size;
 				}
 
 				{
 					std::lock_guard<std::mutex> guard(af.mutex);
 
-					size_t n = 0; // default start point is 0.
+					renderSampleEvent(evt, pos, s, sz);
 
-					// If we are not at offset 0 in current buffer:
-					if(evt.offset > (size_t)pos)
-					{
-						n = evt.offset - pos;
-					}
-
-					size_t end = sz; // default end point is the end of the buffer.
-
-					// Find the end point intra-buffer
-					if((evt.t + end - n) > af.size)
-					{
-						end = af.size - evt.t + n;
-					}
-
-					// This should not be necessary but make absolutely sure that we do
-					// not write over the end of the buffer.
-					if(end > sz)
-					{
-						end = sz;
-					}
-
-					size_t t = 0; // Internal buffer counter
-					if(evt.rampdown == NO_RAMPDOWN)
-					{
-
-#ifdef SSE
-						size_t optend = ((end - n) / N) * N + n;
-
-						// Force source addr to be 16 byte aligned...
-						// (might skip 1 or 2 samples)
-						while((size_t)&evt.buffer[t] % 16)
-						{
-							++t;
-						}
-
-						for(; (n < optend) && (t < evt.buffer_size); n += N)
-						{
-							*(vNsf*)&(s[n]) += *(vNsf*)&(evt.buffer[t]);
-							t += N;
-						}
-#endif
-						for(; (n < end) && (t < evt.buffer_size); ++n)
-						{
-							assert(n >= 0);
-							assert(n < sz);
-
-							assert(t >= 0);
-							assert(t < evt.buffer_size);
-
-							s[n] += evt.buffer[t];
-							++t;
-						}
-					}
-					else
-					{ // Ramp down in progress.
-						for(; (n < end) && (t < evt.buffer_size) && evt.rampdown; ++n)
-						{
-							float scale = (float)evt.rampdown/(float)evt.ramp_start;
-							s[n] += evt.buffer[t] * scale;
-							++t;
-							evt.rampdown--;
-						}
-					}
-
-					// Add internal buffer counter to "global" event counter.
-					evt.t += evt.buffer_size;
-
-					if((evt.t < af.size) && (evt.rampdown != 0))
-					{
-						evt.buffer = audio_cache.next(evt.cache_id, evt.buffer_size);
-					}
-					else
+					if((evt.t >= evt.sample_size) || (evt.rampdown_count == 0))
 					{
 						removeevent = true;
 					}
 
+					if(evt.buffer_ptr >= evt.buffer_size && removeevent == false)
+					{
+						evt.buffer_size = sz;
+						evt.buffer = audio_cache.next(evt.cache_id, evt.buffer_size);
+						evt.buffer_ptr = 0;
+					}
+
 					if(removeevent)
 					{
 						audio_cache.close(evt.cache_id);
@@ -394,28 +412,57 @@ void DrumGizmo::stop()
 std::size_t DrumGizmo::getLatency() const
 {
 	auto latency = input_processor.getLatency();
-	if(enable_resampling)
+	if(enable_resampling && ratio != 0.0)
 	{
-		latency += resamplers.getLatency();
+		// TODO:
+		latency += zita[0].inpsize(); // resampler latency
 	}
 
 	return latency;
 }
 
-int DrumGizmo::samplerate()
+float DrumGizmo::samplerate()
 {
 	return settings.samplerate.load();
 }
 
-void DrumGizmo::setSamplerate(int samplerate)
+void DrumGizmo::setSamplerate(float samplerate)
 {
-	DEBUG(dgeditor, "%s samplerate: %d\n", __PRETTY_FUNCTION__, samplerate);
+	DEBUG(dgeditor, "%s samplerate: %f\n", __PRETTY_FUNCTION__, samplerate);
 	settings.samplerate.store(samplerate);
 
 	// Notify input engine of the samplerate change.
 	ie.setSampleRate(samplerate);
 
-#ifdef WITH_RESAMPLER
-	resamplers.setup(kit.getSamplerate(), settings.samplerate.load());
-#endif/*WITH_RESAMPLER*/
+	auto input_fs = settings.drumkit_samplerate.load();
+	auto output_fs = samplerate;
+	ratio = input_fs / output_fs;
+	settings.resamplig_recommended.store(ratio != 1.0);
+
+	// TODO: Only reallocate the actual amount of samples needed based on the
+	// ratio and the framesize.
+	for(auto& buf : resampler_input_buffer)
+	{
+		buf.reset(new sample_t[MAX_RESAMPLER_BUFFER_SIZE]);
+	}
+
+	for(int c = 0; c < NUM_CHANNELS; ++c)
+	{
+		zita[c].reset();
+		auto nchan = 1u; // mono
+		auto hlen = 72u; // 16 ≤ hlen ≤ 96
+		zita[c].setup(input_fs, output_fs, nchan, hlen);
+
+		// Prefill
+		auto null_size = zita[c].inpsize() - 1;// / 2 - 1;
+		zita[c].inp_data = nullptr;
+		zita[c].inp_count = null_size;
+
+		constexpr auto sz = 4096 * 16;
+		sample_t s[sz];
+		zita[c].out_data = s;
+		zita[c].out_count = sz;
+
+		zita[c].process();
+	}
 }
