@@ -26,9 +26,14 @@
  */
 #pragma once
 
+#include <config.h>
+
 #include <string>
 #include <list>
 #include <array>
+#include <memory>
+
+#include <zita-resampler/resampler.h>
 
 #include "audiooutputengine.h"
 #include "audioinputengine.h"
@@ -37,7 +42,6 @@
 #include "drumkit.h"
 #include "drumkitloader.h"
 #include "audiocache.h"
-#include "chresampler.h"
 #include "settings.h"
 #include "inputprocessor.h"
 
@@ -56,13 +60,14 @@ public:
 	bool run(size_t pos, sample_t *samples, size_t nsamples);
 	void stop();
 
+	void renderSampleEvent(EventSample& evt, int pos, sample_t *s, std::size_t sz);
 	void getSamples(int ch, int pos, sample_t *s, size_t sz);
 
 	//! Get the current engine latency in samples.
 	std::size_t getLatency() const;
 
-	int samplerate();
-	void setSamplerate(int samplerate);
+	float samplerate();
+	void setSamplerate(float samplerate);
 
 	void setFrameSize(size_t framesize);
 
@@ -71,9 +76,7 @@ public:
 	void setRandomSeed(unsigned int seed);
 
 private:
-	static constexpr int MAX_NUM_CHANNELS = 64;
-	static constexpr int RESAMPLER_OUTPUT_BUFFER = 4096;
-	static constexpr int RESAMPLER_INPUT_BUFFER = 64;
+	static constexpr int MAX_RESAMPLER_BUFFER_SIZE = 4096 * 8;
 
 protected:
 	DrumKitLoader loader;
@@ -81,11 +84,8 @@ protected:
 	AudioOutputEngine& oe;
 	AudioInputEngine& ie;
 
-	std::list< Event* > activeevents[MAX_NUM_CHANNELS];
+	std::list< Event* > activeevents[NUM_CHANNELS];
 
-	Resamplers resamplers;
-	sample_t resampler_output_buffer[MAX_NUM_CHANNELS][RESAMPLER_OUTPUT_BUFFER];
-	sample_t resampler_input_buffer[MAX_NUM_CHANNELS][RESAMPLER_INPUT_BUFFER];
 	bool enable_resampling{true};
 
 	std::map<std::string, AudioFile *> audiofiles;
@@ -102,4 +102,8 @@ protected:
 	SettingsGetter settings_getter;
 
 	Random rand;
+	std::array<Resampler, NUM_CHANNELS> zita;
+	std::array<std::unique_ptr<sample_t>, NUM_CHANNELS> resampler_input_buffer;
+	double ratio = 1.0;
+
 };
