@@ -35,7 +35,6 @@
 
 class DrumKit
 {
-	friend class DrumKitParser;
 public:
 	DrumKit();
 	~DrumKit();
@@ -53,19 +52,25 @@ public:
 
 	bool isValid() const;
 
-	std::size_t getSamplerate() const;
+	float getSamplerate() const;
 
 	//! Get the number of audio files (as in single channel) in this drumkit.
 	std::size_t getNumberOfFiles() const;
 
 private:
+	friend class DOMLoader;
+	friend class DOMLoaderTest;
+	friend class DrumKitParser;
+	friend class DrumKitLoader;
+	friend class DrumkitParserTest;
+
 	void* magic{nullptr};
 
 	std::string _file;
 
 	std::string _name;
 	std::string _description;
-	std::size_t _samplerate{0};
+	float _samplerate{44100.0f};
 
 	VersionStr _version;
 };
