@@ -30,23 +30,48 @@
 
 #include <hugin.hpp>
 
-#include "drumkitparser.h"
 #include "drumgizmo.h"
 #include "audioinputenginemidi.h"
+#include "DGDOM.h"
+#include "dgxmlparser.h"
+#include "path.h"
+#include "domloader.h"
+
+#define REFSFILE "refs.conf"
 
 DrumKitLoader::DrumKitLoader(Settings& settings, DrumKit& kit,
                              AudioInputEngine& ie,
-                             Resamplers& resamplers,
                              Random& rand,
                              AudioCache& audio_cache)
 	: settings(settings)
 	, getter(settings)
 	, kit(kit)
 	, ie(ie)
-	, resamplers(resamplers)
 	, rand(rand)
 	, audio_cache(audio_cache)
 {
+	logger =
+		[&](LogLevel level, const std::string& msg)
+		{
+			std::string message;
+			switch(level)
+			{
+			case LogLevel::Info:
+				//message = "[Info]";
+				//break;
+				return; // Ignore info level messages
+			case LogLevel::Warning:
+				message = "[Warning]";
+				break;
+			case LogLevel::Error:
+				message = "[Error]";
+				break;
+			}
+			message += " " + msg + "\n";
+			std::string status = settings.load_status_text.load();
+			status += message;
+			settings.load_status_text.store(status);
+		};
 }
 
 DrumKitLoader::~DrumKitLoader()
@@ -105,10 +130,70 @@ bool DrumKitLoader::loadkit(const std::string& file)
 	// Delete all Channels, Instruments, Samples and AudioFiles.
 	kit.clear();
 
+	// Clear metadata from previously loaded drumkit
+	settings.drumkit_name.store("");
+	settings.drumkit_description.store("");
+	settings.drumkit_version.store("");
+	settings.drumkit_samplerate.store(44100);
+	settings.load_status_text.store("");
+
 	settings.drumkit_load_status.store(LoadStatus::Loading);
 
-	DrumKitParser parser(settings, kit, rand);
-	if(parser.parseFile(file))
+	// Parse drumkit and instrument xml
+
+	settings.has_bleed_control.store(false);
+
+	ConfigFile refs(REFSFILE);
+
+	auto edited_filename(file);
+
+	if(refs.load())
+	{
+		if((file.size() > 1) && (file[0] == '@'))
+		{
+			edited_filename = refs.getValue(file.substr(1));
+		}
+	}
+	else
+	{
+		WARN(drumkitparser, "Error reading refs.conf");
+	}
+
+	DrumkitDOM drumkitdom;
+	std::vector<InstrumentDOM> instrumentdoms;
+	std::string path = getPath(edited_filename);
+	bool parseerror = false;
+	bool ret = parseDrumkitFile(edited_filename, drumkitdom, logger);
+	if(!ret)
+	{
+		WARN(drumkitloader, "Drumkit file parser error: '%s'",
+		     edited_filename.data());
+	}
+
+	parseerror |= !ret;
+
+	for(const auto& ref : drumkitdom.instruments)
+	{
+		instrumentdoms.emplace_back();
+		bool ret = parseInstrumentFile(path + "/" + ref.file, instrumentdoms.back(),
+		                               logger);
+		if(!ret)
+		{
+			WARN(drumkitloader, "Instrument file parser error: '%s'",
+			     edited_filename.data());
+		}
+
+		parseerror |= !ret;
+	}
+
+	DOMLoader domloader(settings, rand);
+	ret = domloader.loadDom(path, drumkitdom, instrumentdoms, kit, logger);
+	if(!ret)
+	{
+		WARN(drumkitloader, "DOMLoader error");
+	}
+	parseerror |= !ret;
+	if(parseerror)
 	{
 		ERR(drumgizmo, "Drumkit parser failed: %s\n", file.c_str());
 		settings.drumkit_load_status.store(LoadStatus::Error);
@@ -121,12 +206,12 @@ bool DrumKitLoader::loadkit(const std::string& file)
 	}
 
 	// Check if there is enough free RAM to load the drumkit.
-	if(!memchecker.enoughFreeMemory(kit))
-	{
-		printf("WARNING: "
-		       "There doesn't seem to be enough RAM available to load the kit.\n"
-		       "Trying to load it anyway...\n");
-	}
+	//if(!memchecker.enoughFreeMemory(kit))
+	//{
+	//	printf("WARNING: "
+	//	       "There doesn't seem to be enough RAM available to load the kit.\n"
+	//	       "Trying to load it anyway...\n");
+	//}
 
 	// Put some information about the kit into the settings
 	settings.drumkit_name = kit.getName();
@@ -134,19 +219,14 @@ bool DrumKitLoader::loadkit(const std::string& file)
 	settings.drumkit_version = kit.getVersion();
 	settings.drumkit_samplerate = kit.getSamplerate();
 
-	loadKit(&kit);
-
-#ifdef WITH_RESAMPLER
-	resamplers.setup(kit.getSamplerate(), settings.samplerate.load());
-#endif/*WITH_RESAMPLER*/
-	settings.resamplig_recommended.store(resamplers.isActive());
+	loadKitAudio(kit);
 
 	DEBUG(loadkit, "loadkit: Success\n");
 
 	return true;
 }
 
-void DrumKitLoader::loadKit(DrumKit *kit)
+void DrumKitLoader::loadKitAudio(const DrumKit& kit)
 {
 //	std::lock_guard<std::mutex> guard(mutex);
 
@@ -157,9 +237,9 @@ void DrumKitLoader::loadKit(DrumKit *kit)
 
 	DEBUG(loader, "cache_enable: %s\n", cache_enable?"true":"false");
 
-	if(cache_enable)
+	auto number_of_files = kit.getNumberOfFiles();
+	if(cache_enable && number_of_files > 0)
 	{
-		auto number_of_files = kit->getNumberOfFiles();
 		auto cache_limit_per_file = cache_limit / number_of_files;
 
 		assert(framesize != 0);
@@ -187,13 +267,13 @@ void DrumKitLoader::loadKit(DrumKit *kit)
 
 	// Count total number of files that need loading:
 	settings.number_of_files.store(0);
-	for(auto& instr_ptr: kit->instruments)
+	for(const auto& instr_ptr: kit.instruments)
 	{
 		settings.number_of_files.fetch_add(instr_ptr->audiofiles.size());
 	}
 
 	// Now actually queue them for loading:
-	for(auto& instr_ptr: kit->instruments)
+	for(const auto& instr_ptr: kit.instruments)
 	{
 		for(auto& audiofile: instr_ptr->audiofiles)
 		{
@@ -204,7 +284,7 @@ void DrumKitLoader::loadKit(DrumKit *kit)
 	DEBUG(loader, "Queued %d (size: %d) AudioFiles for loading.\n",
 	      (int)settings.number_of_files.load(), (int)load_queue.size());
 
-	audio_cache.updateChunkSize(kit->channels.size());
+	audio_cache.updateChunkSize(kit.channels.size());
 
 	semaphore.post(); // Start loader loop.
 }
@@ -289,7 +369,7 @@ void DrumKitLoader::thread_main()
 			filename = audiofile->filename;
 			try
 			{
-				audiofile->load(preload_samples);
+				audiofile->load(logger, preload_samples);
 			}
 			catch(std::bad_alloc&)
 			{
