@@ -31,8 +31,6 @@
 #include <string>
 #include <mutex>
 
-#include <sndfile.h>
-
 #include "audiofile.h"
 #include "audio.h"
 #include "audiocache.h"
@@ -42,6 +40,11 @@ typedef unsigned int timepos_t;
 class Event
 {
 public:
+	Event(channel_t channel, timepos_t offset = 0)
+		: channel(channel), offset(offset)
+	{
+	}
+
 	virtual ~Event()
 	{
 	}
@@ -54,25 +57,25 @@ public:
 	virtual type_t getType() const = 0;
 
 	channel_t channel;
-	timepos_t offset;
+	timepos_t offset; //< Global position (ie. not relative to buffer)
 };
 
-#define NO_RAMPDOWN -1
-class EventSample : public Event
+class EventSample
+	: public Event
 {
 public:
 	EventSample(channel_t c, float g, AudioFile* af,
-	            const std::string& grp, void* instr)
+	            const std::string& grp, std::size_t instrument_id)
+		: Event(c)
+		, cache_id(CACHE_NOID)
+		, gain(g)
+		, t(0)
+		, file(af)
+		, group(grp)
+		, rampdown_count(-1)
+		, ramp_length(0)
+		, instrument_id(instrument_id)
 	{
-		cache_id = CACHE_NOID;
-		channel = c;
-		gain = g;
-		t = 0;
-		file = af;
-		group = grp;
-		instrument = instr;
-		rampdown = NO_RAMPDOWN;
-		ramp_start = 0;
 	}
 
 	Event::type_t getType() const
@@ -80,17 +83,26 @@ public:
 		return Event::sample;
 	}
 
+	bool rampdownInProgress() const
+	{
+		return rampdown_count != -1;
+	}
+
 	cacheid_t cache_id;
 	sample_t* buffer;
-	size_t buffer_size;
+	std::size_t buffer_size;
+	std::size_t buffer_ptr{0}; //< Internal pointer into the current buffer
+	std::size_t sample_size{0}; //< Total number of audio samples in this sample.
 
 	float gain;
-	unsigned int t;
+	unsigned int t; //< Internal sample position.
 	AudioFile* file;
 	std::string group;
-	void* instrument;
-	int rampdown;
-	int ramp_start;
+	int rampdown_count;
+	int ramp_length;
+	std::size_t rampdown_offset{0};
+	float scale{1.0f};
+	std::size_t instrument_id;
 };
 
 class EventQueue
@@ -108,4 +120,3 @@ private:
 	std::multimap<timepos_t, Event*> queue;
 	std::mutex mutex;
 };
-
