@@ -37,13 +37,15 @@
 #include "inputfilter.h"
 
 struct Settings;
+class Random;
 
 class InputProcessor
 {
 public:
 	InputProcessor(Settings& settings,
 	               DrumKit& kit,
-	               std::list<Event*>* activeevents);
+	               std::list<Event*>* activeevents,
+	               Random& random);
 
 	bool process(std::vector<event_t>& events,
 	             std::size_t pos,
@@ -54,10 +56,13 @@ public:
 private:
 	DrumKit& kit;
 	std::list<Event*>* activeevents;
-	bool is_stopping; ///< Is set to true when a TYPE_STOP event has been seen.
+	bool is_stopping; ///< Is set to true when a EventType::Stop event has been seen.
 
 	bool processOnset(event_t& event, std::size_t pos, double resample_ratio);
+	bool processChoke(event_t& event, std::size_t pos, double resample_ratio);
 	bool processStop(event_t& event);
 
 	std::vector<std::unique_ptr<InputFilter>> filters;
+
+	Settings& settings;
 };
