@@ -29,9 +29,11 @@
 #include <string>
 #include <vector>
 #include <memory>
+#include <deque>
 
-#include "rangemap.h"
+#include "rangemap.h" // for v1.0 kits
 #include "powerlist.h"
+#include "sample_selection.h"
 
 #include "sample.h"
 #include "versionstr.h"
@@ -39,18 +41,24 @@
 
 #include "settings.h"
 
+struct Choke
+{
+	std::size_t instrument_id;
+	double choketime;
+};
+
 class Instrument
 {
-	friend class InstrumentParser;
 public:
 	Instrument(Settings& settings, Random& rand);
 	~Instrument();
 
-	Sample* sample(level_t level, size_t pos);
+	const Sample* sample(level_t level, size_t pos);
 
-	std::string getName() const;
-	std::string getDescription() const;
-	std::string getGroup() const;
+	std::size_t getID() const;
+	const std::string& getName() const;
+	const std::string& getDescription() const;
+	const std::string& getGroup() const;
 
 	void setGroup(const std::string& group);
 
@@ -63,27 +71,42 @@ public:
 	//! Get the number of audio files (as in single channel) in this instrument.
 	std::size_t getNumberOfFiles() const;
 
+	float getMaxPower() const;
+	float getMinPower() const;
+
+	const std::vector<Choke>& getChokes();
+
 private:
+	// For unit-tests:
+	friend class DOMLoaderTest;
+
+	// For parser:
+	friend class DOMLoader;
+
 	void* magic;
 
+	std::size_t id;
 	std::string _group;
 	std::string _name;
 	std::string _description;
 
 	VersionStr version;
 
-	RangeMap<level_t, Sample*> samples;
+	RangeMap<level_t, const Sample*> samples;
 
-	void addSample(level_t a, level_t b, Sample* s);
+	void addSample(level_t a, level_t b, const Sample* s);
 	void finalise(); ///< Signal instrument that no more samples will be added.
 
 	std::vector<Sample*> samplelist;
+	std::deque<InstrumentChannel> instrument_channels;
 
 	size_t lastpos;
 	float mod;
 	Settings& settings;
 	Random& rand;
 	PowerList powerlist;
+	std::vector<Choke> chokes;
+	SampleSelection sample_selection;
 };
 
 // typedef std::map< std::string, Instrument > Instruments;
