@@ -24,7 +24,7 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#include <cppunit/extensions/HelperMacros.h>
+#include "dgunit.h"
 
 #include <thread>
 #include <chrono>
@@ -38,21 +38,19 @@
 #define FRAMESIZE 64
 
 class AudioCacheTest
-	: public CppUnit::TestFixture
+	: public DGUnit
 {
-	CPPUNIT_TEST_SUITE(AudioCacheTest);
-	CPPUNIT_TEST(singleChannelNonThreaded);
-	CPPUNIT_TEST(singleChannelThreaded);
-	CPPUNIT_TEST(multiChannelNonThreaded);
-	CPPUNIT_TEST(multiChannelThreaded);
-	CPPUNIT_TEST_SUITE_END();
+public:
+	AudioCacheTest()
+	{
+		DGUNIT_TEST(AudioCacheTest::singleChannelNonThreaded);
+		DGUNIT_TEST(AudioCacheTest::singleChannelThreaded);
+		DGUNIT_TEST(AudioCacheTest::multiChannelNonThreaded);
+		DGUNIT_TEST(AudioCacheTest::multiChannelThreaded);
+	}
 
 	DrumkitCreator drumkit_creator;
 
-public:
-	void setUp() {}
-	void tearDown() {}
-
 	//! Test runner.
 	//! \param filename The name of the file to read.
 	//! \param channel The channel number to do comparison on.
@@ -64,12 +62,12 @@ public:
 		// Reference file:
 		AudioFile audio_file_ref(filename, channel);
 		printf("audio_file_ref.load\n");
-		audio_file_ref.load();
+		audio_file_ref.load(nullptr);
 
 		// Input file:
 		AudioFile audio_file(filename, channel);
 		printf("audio_file.load\n");
-		audio_file.load(4096);
+		audio_file.load(nullptr, 4096);
 
 		Settings settings;
 		AudioCache audio_cache(settings);
@@ -97,7 +95,7 @@ public:
 			// Test pre cache:
 			for(size_t i = 0; i < size; ++i)
 			{
-				CPPUNIT_ASSERT_EQUAL(audio_file_ref.data[offset], samples[i]);
+				DGUNIT_ASSERT_EQUAL(audio_file_ref.data[offset], samples[i]);
 				++offset;
 			}
 
@@ -113,14 +111,15 @@ public:
 						std::this_thread::sleep_for(std::chrono::milliseconds(1));
 						if(--timeout == 0)
 						{
-							CPPUNIT_ASSERT(false); // timeout
+							DGUNIT_ASSERT(false); // timeout
 						}
 					}
 				}
 
+				size = framesize;
 				samples = audio_cache.next(id, size);
 
-				CPPUNIT_ASSERT_EQUAL(std::size_t(0), settings.number_of_underruns.load());
+				DGUNIT_ASSERT_EQUAL(std::size_t(0), settings.number_of_underruns.load());
 
 				for(size_t i = 0; (i < size) && (offset < audio_file_ref.size); ++i)
 				{
@@ -132,7 +131,7 @@ public:
 						       (int)(audio_file_ref.size - offset),
 						       (int)i, (int)size, (int)(size - i));
 					}
-					CPPUNIT_ASSERT_EQUAL(audio_file_ref.data[offset], samples[i]);
+					DGUNIT_ASSERT_EQUAL(audio_file_ref.data[offset], samples[i]);
 					++offset;
 				}
 			}
@@ -202,4 +201,4 @@ public:
 };
 
 // Registers the fixture into the 'registry'
-CPPUNIT_TEST_SUITE_REGISTRATION(AudioCacheTest);
+static AudioCacheTest test;
