@@ -24,7 +24,7 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#include <cppunit/extensions/HelperMacros.h>
+#include "dgunit.h"
 
 #include <thread>
 #include <chrono>
@@ -37,48 +37,48 @@ class AudioOutputEngineDummy
 	: public AudioOutputEngine
 {
 public:
-	bool init(const Channels& channels) { return true; }
+	bool init(const Channels& channels) override { return true; }
 
-	void setParm(const std::string& parm, const std::string& value) {}
+	void setParm(const std::string& parm, const std::string& value) override {}
 
-	bool start() { return true; }
-	void stop() {}
+	bool start() override { return true; }
+	void stop() override {}
 
-	void pre(size_t nsamples) {}
-	void run(int ch, sample_t *samples, size_t nsamples) {}
-	void post(size_t nsamples) {}
-	bool isFreewheeling() const { return true; }
+	void pre(size_t nsamples) override {}
+	void run(int ch, sample_t *samples, size_t nsamples) override {}
+	void post(size_t nsamples) override {}
+	std::size_t getSamplerate() const override { return 44100; }
+	bool isFreewheeling() const override { return true; }
 };
 
 class AudioInputEngineDummy
 	: public AudioInputEngine
 {
 public:
-	bool init(const Instruments& instruments) { return true; }
+	bool init(const Instruments& instruments) override { return true; }
 
-	void setParm(const std::string& parm, const std::string& value) {}
+	void setParm(const std::string& parm, const std::string& value) override {}
 
-	bool start() { return true; }
-	void stop() {}
+	bool start() override { return true; }
+	void stop() override {}
 
-	void pre() {}
-	void run(size_t pos, size_t len, std::vector<event_t>& events) {}
-	void post() {}
-	bool isFreewheeling() const { return true; }
+	void pre() override {}
+	void run(size_t pos, size_t len, std::vector<event_t>& events) override {}
+	void post() override {}
+	void setSampleRate(double sample_rate) override {}
+	bool isFreewheeling() const override { return true; }
 };
 
-class test_engine : public CppUnit::TestFixture
+class test_engine : public DGUnit
 {
-	CPPUNIT_TEST_SUITE(test_engine);
-	CPPUNIT_TEST(loading);
-	CPPUNIT_TEST_SUITE_END();
+public:
+	test_engine()
+	{
+		DGUNIT_TEST(test_engine::loading);
+	}
 
 	DrumkitCreator drumkit_creator;
 
-public:
-	void setUp() {}
-	void tearDown() {}
-
 	void loading()
 	{
 		Settings settings;
@@ -119,4 +119,4 @@ public:
 };
 
 // Registers the fixture into the 'registry'
-CPPUNIT_TEST_SUITE_REGISTRATION(test_engine);
+static test_engine test;
